==> jc-1.4.0.tar.gz: java/rmi/UnexpectedException.h <==
// public class java.rmi.UnexpectedException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class e400150b2c92a109 java_rmi_UnexpectedException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_UnexpectedException_H_
#define _JC_java_rmi_UnexpectedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_UnexpectedException$sub_refs	_jc_java_rmi_UnexpectedException$sub_refs;
typedef struct _jc_java_rmi_UnexpectedException$sub_nonrefs	_jc_java_rmi_UnexpectedException$sub_nonrefs;
typedef struct _jc_java_rmi_UnexpectedException$refs	_jc_java_rmi_UnexpectedException$refs;
typedef struct _jc_java_rmi_UnexpectedException$nonrefs	_jc_java_rmi_UnexpectedException$nonrefs;
typedef struct _jc_java_rmi_UnexpectedException$object	_jc_java_rmi_UnexpectedException$object;

typedef struct _jc_java_rmi_UnexpectedException$fields_struct	_jc_java_rmi_UnexpectedException$fields_struct;
typedef const struct _jc_java_rmi_UnexpectedException$vmethods	_jc_java_rmi_UnexpectedException$vmethods;
typedef const struct _jc_java_rmi_UnexpectedException$vtable	_jc_java_rmi_UnexpectedException$vtable;
typedef const struct _jc_java_rmi_UnexpectedException$vtype	_jc_java_rmi_UnexpectedException$vtype;

// Class fields structure
struct _jc_java_rmi_UnexpectedException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_UnexpectedException$fields_struct _jc_java_rmi_UnexpectedException$class_fields;

// Constructors
extern void _jc_java_rmi_UnexpectedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_UnexpectedException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_UnexpectedException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_UnexpectedException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_java_rmi_UnexpectedException$vmethods {
};

// Vtable
struct _jc_java_rmi_UnexpectedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_UnexpectedException$vmethods	java_rmi_UnexpectedException;
};

// Vtype
struct _jc_java_rmi_UnexpectedException$vtype {
	_jc_type			type;
	_jc_java_rmi_UnexpectedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_UnexpectedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_UnexpectedException$refs {
    _jc_java_rmi_UnexpectedException$sub_refs	java_rmi_UnexpectedException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_UnexpectedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_UnexpectedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_UnexpectedException$sub_nonrefs	java_rmi_UnexpectedException;
};

// Object instance structure
struct _jc_java_rmi_UnexpectedException$object {
	_jc_java_rmi_UnexpectedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_UnexpectedException$vtype	*vtype;
	_jc_java_rmi_UnexpectedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_UnexpectedException$vtype _jc_java_rmi_UnexpectedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_UnexpectedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_UnexpectedException$class_object;

#endif	/* _JC_java_rmi_UnexpectedException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/UnexpectedException.h <==
// public class java.rmi.UnexpectedException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class e400150b2c92a109 java_rmi_UnexpectedException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_UnexpectedException_H_
#define _JC_java_rmi_UnexpectedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_UnexpectedException$sub_refs	_jc_java_rmi_UnexpectedException$sub_refs;
typedef struct _jc_java_rmi_UnexpectedException$sub_nonrefs	_jc_java_rmi_UnexpectedException$sub_nonrefs;
typedef struct _jc_java_rmi_UnexpectedException$refs	_jc_java_rmi_UnexpectedException$refs;
typedef struct _jc_java_rmi_UnexpectedException$nonrefs	_jc_java_rmi_UnexpectedException$nonrefs;
typedef struct _jc_java_rmi_UnexpectedException$object	_jc_java_rmi_UnexpectedException$object;

typedef struct _jc_java_rmi_UnexpectedException$fields_struct	_jc_java_rmi_UnexpectedException$fields_struct;
typedef const struct _jc_java_rmi_UnexpectedException$vmethods	_jc_java_rmi_UnexpectedException$vmethods;
typedef const struct _jc_java_rmi_UnexpectedException$vtable	_jc_java_rmi_UnexpectedException$vtable;
typedef const struct _jc_java_rmi_UnexpectedException$vtype	_jc_java_rmi_UnexpectedException$vtype;

// Class fields structure
struct _jc_java_rmi_UnexpectedException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_UnexpectedException$fields_struct _jc_java_rmi_UnexpectedException$class_fields;

// Constructors
extern void _jc_java_rmi_UnexpectedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_UnexpectedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_UnexpectedException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_UnexpectedException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_UnexpectedException$vmethods {
};

// Vtable
struct _jc_java_rmi_UnexpectedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_UnexpectedException$vmethods	java_rmi_UnexpectedException;
};

// Vtype
struct _jc_java_rmi_UnexpectedException$vtype {
	_jc_type			type;
	_jc_java_rmi_UnexpectedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_UnexpectedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_UnexpectedException$refs {
    _jc_java_rmi_UnexpectedException$sub_refs	java_rmi_UnexpectedException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_UnexpectedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_UnexpectedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_UnexpectedException$sub_nonrefs	java_rmi_UnexpectedException;
};

// Object instance structure
struct _jc_java_rmi_UnexpectedException$object {
	_jc_java_rmi_UnexpectedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_UnexpectedException$vtype	*vtype;
	_jc_java_rmi_UnexpectedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_UnexpectedException$vtype _jc_java_rmi_UnexpectedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_UnexpectedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_UnexpectedException$class_object;

#endif	/* _JC_java_rmi_UnexpectedException_H_ */
